;(function($){
    /**
     * 将字符串类型的日期格式化
     * @date 需要格式化的日期，字符串类型
     * @format 格式化后的格式，eg:format="yyyy-MM-dd hh:mm:ss";
     * 返回结果
     */
    template.helper('dateFormat', function (date, format) {
        if (typeof date == "string") {
            if (date.indexOf('-') > -1) {
                date= new Date(date.split('-')[0],date.split('-')[1]*1-1,date.split('-')[2]);
            }else if (date.indexOf('/') > -1) {
                date= new Date(date.split('/')[0],date.split('/')[1]*1-1,date.split('/')[2]);
            }else{
                date= new Date(date.substring(0,4),date.substring(4,6)*1-1,date.substring(6,8));
            }
        }
        date = new Date(date);

        var map = {
            "M": date.getMonth() + 1, //月份
            "d": date.getDate(), //日
            "h": date.getHours(), //小时
            "m": date.getMinutes(), //分
            "s": date.getSeconds(), //秒
            "q": Math.floor((date.getMonth() + 3) / 3), //季度
            "S": date.getMilliseconds() //毫秒
        };
        format = format.replace(/([yMdhmsqS])+/g, function(all, t){
            var v = map[t];
            if(v !== undefined){
                if(all.length > 1){
                    v = '0' + v;
                    v = v.substr(v.length-2);
                }
                return v;
            }
            else if(t === 'y'){
                return (date.getFullYear() + '').substr(4 - all.length);
            }
            return all;
        });
        return format;
    });
    /**
     * 将字符串时间进行格式化
     * @time 需要格式化的时间，字符串类型
     * @format 格式化后的格式，eg:format="hh:mm:ss";
     * 返回结果
     */
    template.helper('timeFormat', function (time) {
        if (typeof time == "string") {
            if(time.length == 7){
                time = '0'+time;
            }
        }
        var format = time.substring(0,2)+':'+time.substring(2,4);
        return format;
    });
    /**
     * 涨跌幅，上涨为红色(red)，下跌为绿色(green)，不跌不涨为黑色
     * @data 需要格式化的数据，字符串类型
     * 返回结果
     */
    template.helper('fluctuation', function (data) {
        if (Com.postiveFloorNumber(data)) {
            return 'red';
        }else if(data.indexOf('-')!=-1){
            return 'green';
        }else{
            return '';
        }
    });
    /**
     * 涨跌幅的正数需要加上‘+’号，负数和0不用加
     * @data 需要格式化的数据，字符串类型
     * 返回结果
     */
    template.helper('positive', function (data) {
        if (Com.postiveFloorNumber(data)) {
            return '+'+data;
        }else{
            return data;
        }
    });
    /**
     * 取绝对值
     * @data 需要处理的数据，字符串类型
     * 返回结果
     */
    template.helper('abs', function (data) {
        return Math.abs(data);
    });
    /**
     * 基金业绩图表年度、季度坐标处理
     * @data 需要处理的数据，字符串类型
     * 返回结果
     */
    template.helper('yearFormat', function (data) {
        if (data.indexOf('季度')>-1) {
            return (data.split('季度')[0]).replace('年','Q');
        }else{
            return (data.split('度'))[0];
        }
    });
    /**
     * 计算业绩排行的等级
     * @data 需要处理的数据，字符串类型
     * 返回结果
     */
    template.helper('grade', function (profitRank,profitRank_total) {
        if (profitRank=='') {
            return 0
        }
        var grade = profitRank/profitRank_total
        if (grade<0.25){
            return 4;
        }else if(grade>=0.25&&grade<0.5){
            return 3;
        }else if(grade>=0.5&&grade<0.75){
            return 2;
        }else if(grade>=0.75&&grade<1){
            return 1;
        }else{
            return 4;
        }
    });
    /**
     * 基金业绩,数据检查和处理grade2
     * profitRank和profitRank_total只要有一个为空，返回“--”
     * @action 对数据进行处理的方式
     * 1、处理profitRank
     * 2、处理profitRank_total
     * 返回结果
     */
    template.helper('grade2', function (profitRank,profitRank_total,action) {
        if(action == 3){
            if (profitRank==undefined||profitRank==''||profitRank_total==undefined||profitRank_total=='') {
                return 'none';
            }else{
                return '';
            }
        }
        if (profitRank==undefined||profitRank==''||profitRank_total==undefined||profitRank_total=='') {
            return '--';
        }else{
            if(action == 1) {
                return profitRank;
            }else if(action == 2){
                return profitRank_total;
            }
        }
    });
    

    /**
     * 数据检查和处理dataCheck,简称DC
     * @data 需要处理的数据，字符串类型
     * @action 对数据进行处理的方式
     * 1、是否为空，为空返回"--"
     * 2、是否为空，为空返回"--",不为空(data*100).toFixed2(2)
     * 3、是否为空，为空返回"--",不为空(data*1).toFixed2(2)
     * 4、是涨还是跌，涨返回red，跌返回green，否则返回空
     * 5、用于处理雷达图的数据，如果是不存在或者为空，返回0，否则返回(1-data)*100
     * 6、是否为空，为空返回"--",不为空(1-data)*100.toFixed(0)
     * 7、是否为空，为空返回"--",不为空data*100.toFixed(0)
     * 8、是否为空，为空返回0,不为空data*100
     * 返回结果
     */
    template.helper('DC', function (data,action) {
        if (action == 1) {
            if (data==undefined||data==="") {
                return '--';
            }else{
                return data;
            }
        }else if (action == 2) {
            if (data==undefined||data==="") {
                return '--';
            }else{
                return (data*100).toFixed2(2);
            }
        }else if (action == 3) {
            if (data==undefined||data==="") {
                return '--';
            }else{
                return (data*1).toFixed2(2);
            }
        }else if (action == 4) {
            if (data==undefined||data===""||data==0) {
                return '';
            }else{
                data = data.toString();
                if(data.indexOf('-') > -1){
                    return 'green';
                }else{
                    return 'red';
                }
            } 
        }else if (action == 5) {
            if (data==undefined||data==="") {
                return 0;
            }else{
                return (1-data)*100;
            }
        }else if (action == 6) {
            if (data==undefined||data==="") {
                return '--';
            }else{
                return ((1-data)*100).toFixed(0);
            }
        }else if (action == 7) {
            if (data==undefined||data==="") {
                return '--';
            }else{
                return (data*100).toFixed(0);
            }
        }else if (action == 8) {
            if (data==undefined||data==="") {
                return 0;
            }else{
                return data*100;
            }
        }
        
    });
})(Zepto);