
/**
 * 文本框根据输入内容自适应高度
 * @elem                {HTMLElement}输入框元素
 * @extra               {Number}设置光标与输入框保持的距离(默认0)
 * @maxHeight           {Number}设置最大高度(可选)
 */
function autoTextarea (elem, extra, maxHeight) {
    extra = extra || 0;
    var isFirefox = !!document.getBoxObjectFor || 'mozInnerScreenX' in window,
        isOpera = !!window.opera && !!window.opera.toString().indexOf('Opera'),
        addEvent = function (type, callback) {
            elem.addEventListener ?
                elem.addEventListener(type, callback, false) :
                elem.attachEvent('on' + type, callback);
        },
        getStyle = elem.currentStyle ? function (name) {
            var val = elem.currentStyle[name];

            if (name === 'height' && val.search(/px/i) !== 1) {
                var rect = elem.getBoundingClientRect();
                return rect.bottom - rect.top -
                    parseFloat(getStyle('paddingTop')) -
                    parseFloat(getStyle('paddingBottom')) + 'px';
            }

            return val;
        } : function (name) {
            return getComputedStyle(elem, null)[name];
        },
        minHeight = parseFloat(getStyle('height'));

    elem.style.resize = 'none';

    var change = function () {
        var scrollTop, height,
            padding = 0,
            style = elem.style;

        if (elem._length === elem.value.length) return;
        elem._length = elem.value.length;

        if (!isFirefox && !isOpera) {
            padding = parseInt(getStyle('paddingTop')) + parseInt(getStyle('paddingBottom'));
        }
        scrollTop = document.body.scrollTop || document.documentElement.scrollTop;

        elem.style.height = minHeight + 'px';
        if (elem.scrollHeight > minHeight) {
            if (maxHeight && elem.scrollHeight > maxHeight) {
                height = maxHeight - padding;
                style.overflowY = 'auto';
            } else {
                height = elem.scrollHeight - padding;
                style.overflowY = 'hidden';
            }
            style.height = height + extra + 'px';
            scrollTop += parseInt(style.height) - elem.currHeight;
            document.body.scrollTop = scrollTop;
            document.documentElement.scrollTop = scrollTop;
            elem.currHeight = parseInt(style.height);
        }
    };

    addEvent('propertychange', change);
    addEvent('input', change);
    addEvent('focus', change);
    change();
}

//地区init
function areaSelectInit(){
  //检索出省份列表
  creatList(window.__DATA.Provinces, __DATA.PICKER_CONFIG.first, false);
  //新建picker
  __DATA.picker = new Picker({
  	data: [__DATA.PICKER_CONFIG.first, __DATA.PICKER_CONFIG.second, __DATA.PICKER_CONFIG.third],
    selectedIndex: __DATA.PICKER_CONFIG.selected,
  	title: '地址选择'
  });
  //picker选中确定
  __DATA.picker.on('picker.select', function (selectedVal, selectedIndex) {
    setContactAddr(selectedIndex);
  });
  //picker某一列滚动停止
  __DATA.picker.on('picker.change', function (index, selectedIndex) {
    if (index === 0){  //滚动省份
      firstChange();
    } else if (index === 1) {  //滚动市级
      secondChange();
    }
    //滚动第一列省份
    function firstChange() {
      __DATA.PICKER_CONFIG.second = [];
      __DATA.PICKER_CONFIG.third = [];
      __DATA.PICKER_CONFIG.checked[0] = selectedIndex;
      var firstCity = __DATA.PICKER_CONFIG.first[selectedIndex];

      //获取第二列数据
      getAreaData(2, __DATA.PICKER_CONFIG.first[selectedIndex]["value"],setPickerData);

    }
    //滚动第二列市级
    function secondChange() {
      __DATA.PICKER_CONFIG.third = [];
      __DATA.PICKER_CONFIG.checked[1] = selectedIndex;
      var first_index = __DATA.PICKER_CONFIG.checked[0];
      //获取第三列数据
      getAreaData(3, __DATA.PICKER_CONFIG.second[selectedIndex]["value"],setPickerData);
    }
    __DATA.PICKER_CONFIG.show = false;
  });

  $('#select_contact').on('click', function () {
    // 检索出市级列表
    if(!__DATA.PICKER_CONFIG.inited){
      __DATA.PICKER_CONFIG.inited = true;
      if(document.querySelector("#contact_addr").value=="" && __DATA.userinfo.ucAddress){
        getAreaByLevel(1, __DATA.userinfo.ucAddress);
      }
      getAreaData(2, __DATA.PICKER_CONFIG.first[__DATA.PICKER_CONFIG.checked[0]]["value"],setPickerData);
    }
  	__DATA.picker.show();
    __DATA.PICKER_CONFIG.show = true;
    if(__DATA.PICKER_CONFIG.show){
      setTimeout(function(){
        __DATA.picker.scrollColumn(0, __DATA.PICKER_CONFIG.checked[0])
      },0);
    }
  });
  //填充初始化邮政编码
  getAreaByLevel(1, __DATA.userinfo.ucAddress);
  getAreaData(2, __DATA.PICKER_CONFIG.first[__DATA.PICKER_CONFIG.checked[0]]["value"],setPickerData);
}

function setContactAddr(selectedIndex){
  var text1 = __DATA.PICKER_CONFIG.first[selectedIndex[0]].text;
  var text2 = __DATA.PICKER_CONFIG.second[selectedIndex[1]].text;
  var text3 = __DATA.PICKER_CONFIG.third[selectedIndex[2]] ? __DATA.PICKER_CONFIG.third[selectedIndex[2]].text : '';

  __DATA.userinfo.zipcode = __DATA.PICKER_CONFIG.third[selectedIndex[2]].zipcode;
  document.querySelector("#zipcode").value=__DATA.userinfo.zipcode;

  document.querySelector("#show_contact").innerText = text1  + text2  + text3;
  document.querySelector("#contact_addr").value = text1  + text2  + text3;
}

// 创建可选地区列表
function creatList(obj, list, clear){
  if(clear){
    list.splice(0,list.length)
  }
  obj.forEach(function(item, index, arr){
  var temp = new Object();
  temp.text = item.name;
  temp.value = item.code;
  temp.sname = item.sname;
  temp.zipcode = item.zipcode;
  list.push(temp);
  })
}

//根据ocr识别的证件地址查询省市区
function getAreaByLevel(level, address){
  var checked = 0;
  __DATA._addr = address;
  if(level ==1){//识别省份
    for(var i1 = 0; i1 < __DATA.PICKER_CONFIG.first.length; i1++){
      if (address.indexOf(__DATA.PICKER_CONFIG.first[i1]["text"])==0) {
        __DATA.PICKER_CONFIG.checked[0] = i1;
        __DATA.PICKER_CONFIG.selected[0] =i1;
        if(__DATA.PICKER_CONFIG.first[i1]["zipcode"]){
          __DATA.PICKER_CONFIG.zipcode = __DATA.PICKER_CONFIG.first[i1]["zipcode"];
        }
        __DATA._addr = address.substring(__DATA.PICKER_CONFIG.first[i1]["text"]["length"]);
        break;
      }
    }
  }else if(level==2){//识别市
    for(var i2 = 0; i2 < __DATA.PICKER_CONFIG.second.length; i2++){
      if (address.indexOf(__DATA.PICKER_CONFIG.second[i2]["text"])==0) {
        __DATA.PICKER_CONFIG.checked[1] = i2;
        __DATA.PICKER_CONFIG.selected[1] =i2;
        if(__DATA.PICKER_CONFIG.second[i2]["zipcode"]){
          __DATA.PICKER_CONFIG.zipcode = __DATA.PICKER_CONFIG.second[i2]["zipcode"];
        }
        __DATA._addr = address.substring(__DATA.PICKER_CONFIG.second[i2]["text"]["length"]);
        break;
      }
    }
    if(__DATA.PICKER_CONFIG.show){
      setTimeout(function(){
        __DATA.picker.scrollColumn(1, __DATA.PICKER_CONFIG.checked[1])
      },0);
    }
  }else if(level == 3) {
    for(var i3 = 0; i3 < __DATA.PICKER_CONFIG.third.length; i3++){
      if (address.indexOf(__DATA.PICKER_CONFIG.third[i3]["text"])==0) {
        __DATA.PICKER_CONFIG.checked[2] = i3;
        __DATA.PICKER_CONFIG.selected[2] =i3;
        if(__DATA.PICKER_CONFIG.third[i3]["zipcode"]){
          __DATA.PICKER_CONFIG.zipcode = __DATA.PICKER_CONFIG.third[i3]["zipcode"];
        }
        __DATA._addr = address.substring(__DATA.PICKER_CONFIG.third[i3]["text"]["length"]);
        break;
      }
    }
    if(__DATA.PICKER_CONFIG.show){
      setTimeout(function(){
        __DATA.picker.scrollColumn(2, __DATA.PICKER_CONFIG.checked[2])
      },0);
    }
    document.querySelector("#zipcode").value = __DATA.PICKER_CONFIG.zipcode
  }
}

//根据ocr信息初始化联系地址
function initShowContractAddr(){
  var show_contact = "";
  //截取省份
  var _addr = __DATA.userinfo.ucAddress;
  var addrs = _addr.split(/([省|自治区|行政区|市])/);
  var t1 = addrs.length >= 2? addrs[0] + addrs[1]:"";
  //截取市
  _addr = _addr.substring(t1.length);
  addrs = _addr.split(/([市|盟|自治州|地区])/);
  var t2 = addrs.length >= 2? addrs[0] + addrs[1]:"";
  //截取区县
  _addr = _addr.substring(t2.length);
  addrs = _addr.split(/([区|县|市|自治县|旗])/);
  var t3 = addrs.length >= 2? addrs[0] + addrs[1]:"";
  show_contact = t1 + t2 + t3;
  document.querySelector("#show_contact").innerHTML = t1 + t2 + t3;
  document.querySelector("#textarea_auto").value = __DATA.userinfo.ucAddress.substring(show_contact.length);
}

//查询地区列表信息
function getAreaData(level, code){
  var callback = arguments[2] || null;
  Com.ajaxLoading();

  var param={};
  param['ofcode']=ofcode;
  Com.ajax({
    url: Com.getInterfaceOrigin()+"/gsbp/openaccount/getDistrictInfo/1.0?code="+code+"&level="+level,
    data: param,
    dataType:'json',
    type:'get',
    isTradeLogin:false,
    success: function (respone) {
      if (respone != null && respone.result[0].code == 0) {
        typeof callback=="function" && callback(respone.data, level);
      }else if(respone.result[0].code == '11' || respone.result[0].code == '18' || respone.result[0].code == '19'){
        //document.getElementById("confirmBtn").removeAttribute("disabled");
        return false;
      }else {
        Com.showNativeAlert('',respone.result[0].msg,["确定"]);
      }
      Com.ajaxLoaded();
    },
    error:function(){

    }
  });
}

//查询推荐人信息
function getIntroducer(){
  Com.ajaxLoading();

  var param={};
  Com.ajax({
    url: Com.getInterfaceOrigin()+'/gsbp/openaccount/getIntroducer/1.0',
    data: param,
    dataType:'json',
    type:'post',
    isTradeLogin:false,
    success: function (respone) {
      if (respone != null && respone.result[0].code == 0) {
        __DATA.userinfo.broker = respone.data[0].broker;
        __DATA.userinfo.pro_mobile = respone.data[0].pro_mobile;
      }else if(respone.result[0].code == '11' || respone.result[0].code == '18' || respone.result[0].code == '19'){
        //document.getElementById("confirmBtn").removeAttribute("disabled");
        return false;
      }else {
        Com.showNativeAlert('',respone.result[0].msg,["确定"]);
      }
      Com.ajaxLoaded();
    },
    error:function(){

    }
  });

}

//查询地区数据处理
function setPickerData(data, level){
  if(data && data.length > 0){
    if(level==2){
      creatList(data, __DATA.PICKER_CONFIG.second, true);

      __DATA.PICKER_CONFIG.checked[1] = __DATA.PICKER_CONFIG.checked[1] || 0;
      __DATA.PICKER_CONFIG.checked[2] = __DATA.PICKER_CONFIG.checked[2] || 0;
      if(__DATA.PICKER_CONFIG.show){
        __DATA.picker.refillColumn(1, __DATA.PICKER_CONFIG.second);
        __DATA.picker.scrollColumn(1, __DATA.PICKER_CONFIG.checked[1])
        __DATA.picker.refillColumn(2, __DATA.PICKER_CONFIG.third);
        __DATA.picker.scrollColumn(2, __DATA.PICKER_CONFIG.checked[2])
      }
      if(document.querySelector("#contact_addr").value=="" && __DATA.userinfo.ucAddress){
        getAreaByLevel(2, __DATA._addr);
      }
      getAreaData(3 ,__DATA.PICKER_CONFIG.second[__DATA.PICKER_CONFIG.checked[1]]["value"], setPickerData);
    }else if(level==3){
      creatList(data, __DATA.PICKER_CONFIG.third, true);

      __DATA.PICKER_CONFIG.checked[2] = __DATA.PICKER_CONFIG.checked[2] || 0;
      if(__DATA.PICKER_CONFIG.show){
        __DATA.picker.refillColumn(2, __DATA.PICKER_CONFIG.third);
        __DATA.picker.scrollColumn(2, __DATA.PICKER_CONFIG.checked[2])
      }
      if(document.querySelector("#contact_addr").value=="" && __DATA.userinfo.ucAddress){
        getAreaByLevel(3, __DATA._addr);
      }
    }
  }else{
    if(level==2){
      __DATA.PICKER_CONFIG.second = [{text: '', value: 0}];
      __DATA.PICKER_CONFIG.third = [{text: '', value: 0}];
      __DATA.PICKER_CONFIG.checked[1] = 0;
      __DATA.PICKER_CONFIG.checked[2] = 0;
      if(__DATA.PICKER_CONFIG.show){
        __DATA.picker.refillColumn(1, __DATA.PICKER_CONFIG.second);
        __DATA.picker.refillColumn(2, __DATA.PICKER_CONFIG.third);
        __DATA.picker.scrollColumn(1, 0)
        __DATA.picker.scrollColumn(2, 0)
      }
    }else if(level==3) {
      __DATA.PICKER_CONFIG.third = [{text: '', value: 0}];
      __DATA.PICKER_CONFIG.checked[2] = 0;
      if(__DATA.PICKER_CONFIG.show){
        __DATA.picker.refillColumn(2, __DATA.PICKER_CONFIG.third);
        __DATA.picker.scrollColumn(2, 0)
      }
    }
  }
}

//textarea自适应高度
function initTxtArea(id){
    var text = document.getElementById(id);
    autoTextarea(text);
}

function pageInit(){
    //第一步
    if(window.__DATA.hash == "#page1"){

      Com.nativeGobackListener(0);
      //地区选择控件初始化
      areaSelectInit();
      //学历、职业、行业联动
      //linkSelect();
      if(__DATA.PICKER_CONFIG.inited){
        setContactAddr(__DATA.PICKER_CONFIG.selected);
      }else{
        initShowContractAddr();
      }

      //textarea自适应高度
      initTxtArea("textarea_auto");
      initTxtArea("ucAddress");
    }else if(window.__DATA.hash =="#page2"){
      Com.nativeGobackListener(1,function(){
        history.back();
      });
      //查询推荐人信息
      getIntroducer();
      //修改受益人类型
      document.querySelector("#BenefiType").onchange = function(e){
        if(e.target.value==1){
          $(".benefi-tr").removeClass("hide");
        }else{
          $(".benefi-tr").addClass("hide");
        }
      }
      document.querySelector("#creditFlag").onchange = function(e){
        if(e.target.value==1){
          $(".creditRecord-tr").removeClass("hide");
        }else{
          $(".creditRecord-tr").addClass("hide");
        }
      }
      document.querySelector("#switch-btn").onclick = function(){
        __DATA.userinfo.lowincome = document.querySelector("#lowincome").checked? 1:0;
      }
      document.querySelector("#broker").onchange = function(e){
        __DATA.userinfo.broker = e.target.value
      }
      document.querySelector("#pro_mobile").onchange = function(e){
        __DATA.userinfo.pro_mobile = e.target.value
      }
      $(".cacheInput").on("change",function(e){
        var name = e.target.name;
        if(name=="BenefiCardEndDate" && e.target.value=="长期有效"){
          __DATA.userinfo[name] = "30000101";
        }else{
          __DATA.userinfo[name] = e.target.value
        }
      })

      $(".contract-href").bind("click",function(e){
        var item = e.target.dateset? e.target.dataset.item : e.target.getAttribute("data-item");
        Com.newWebViewOpenPage('',{'pageUrl':Com.getOrigin()+'/asset/openAct/pages/contract.html?item=' + item});
        //location.href = "contract.html?item=" + item;
      })

      initTxtArea("textarea_auto");
    }
    setDateInput();
    setLongDateBtn();
    setPickers();
}

//下一步
function gotoNext(){
  if(__DATA.hash=="#page1"){
    toPage2();
  }else if(__DATA.hash=="#page2"){
    beforeSubmit();
    //Com.showNativeAlert('',respone.result[0].msg,["确定"]);
  }
}

//到第二页
function toPage2(){
  var ucName = document.querySelector("#ucName").value;
  var ucNumber = document.querySelector("#ucNumber").value;
  var contact_addr = document.querySelector("#contact_addr").value;  //联系地址
  var textarea_auto = document.querySelector("#textarea_auto").value;  //联系地址详情地址
  var education = document.querySelector("#EDUCATION").value;  //学历
  var occu_extype = document.querySelector("#OCCU_EXTYPE").value;  //职业
  var cif_trade = document.querySelector("#CIF_TRADE").value; //行业
  var ucNative = document.querySelector("#ucNative").value;  //籍贯
  var ucIssueUint = document.querySelector("#ucIssueUint").value; //发证机关
  var ucAddress = document.querySelector("#ucAddress").value;  //证件地址
  var ucEndDate = document.querySelector("#ucEndDate").value;  //证件有效期
  var zipcode = document.querySelector("#zipcode").value;  //证件有效期

  if(contact_addr=="" && document.querySelector("#show_contact").innerText!=""){
    contact_addr = document.querySelector("#show_contact").innerText;
  }

  if(ucName==""){
    Com.showNativeAlert("","姓名不能为空",["确定"]);
    //console.log("姓名不能为空");
    return false;
  }

  if(ucNumber==""){
    Com.showNativeAlert("","身份证号不能为空",["确定"]);
    //console.log("身份证号不能为空");
    return false;
  }
  var validMsg = identityCodeValid(ucNumber);
  if(validMsg!=""){
    Com.showNativeAlert("",validMsg,["确定"]);
    //console.log("身份证号不能为空");
    return false;
  }

  if(contact_addr==""){
    Com.showNativeAlert("","联系地址不能为空",["确定"]);
    //console.log("联系地址不能为空");
    return false;
  }

  if(textarea_auto==""){
    Com.showNativeAlert("","详情地址不能为空",["确定"]);
    //console.log("详情地址不能为空");
    return false;
  }

  if(zipcode==""){
    Com.showNativeAlert("","邮编不能为空",["确定"]);
    //console.log("详情地址不能为空");
    return false;
  }

  if(!education || education==""){
    Com.showNativeAlert("","请选择学历",["确定"]);
    //console.log("请选择学历");
    return false;
  }

  if(!occu_extype || occu_extype==""){
    Com.showNativeAlert("","请选择职业",["确定"]);
    //console.log("请选择职业");
    return false;
  }

  if(!cif_trade || cif_trade==""){
    Com.showNativeAlert("","请选择行业",["确定"]);
    //console.log("请选择行业");
    return false;
  }

  if(ucNative==""){
    Com.showNativeAlert("","籍贯不能为空",["确定"]);
    //console.log("籍贯不能为空");
    return false;
  }

  if(ucIssueUint==""){
    Com.showNativeAlert("","发证机关不能为空",["确定"]);
    //console.log("发证机关不能为空");
    return false;
  }

  if(ucAddress==""){
    Com.showNativeAlert("","证件地址不能为空",["确定"]);
    //console.log("证件地址不能为空");
    return false;
  }

  if(ucEndDate==""){
    Com.showNativeAlert("","证件有效期不能为空",["确定"]);
    //console.log("证件有效期不能为空");
    return false;
  }
  ucEndDate = ucEndDate=="长期有效"? "30000101":ucEndDate;
  __DATA.userinfo.ucName = ucName;
  __DATA.userinfo.ucNumber = ucNumber;
  __DATA.userinfo.ucNative = ucNative;
  __DATA.userinfo.EDUCATION = education;
  __DATA.userinfo.OCCU_EXTYPE = occu_extype;
  __DATA.userinfo.CIF_TRADE = cif_trade;
  __DATA.userinfo.ucAddress = ucAddress;
  __DATA.userinfo.zipcode = zipcode;
  __DATA.userinfo.ucEndDate = ucEndDate;
  __DATA.userinfo.ucIssueUint = ucIssueUint;
  __DATA.userinfo.contact_addr = contact_addr;
  __DATA.userinfo.contact_detail_addr = textarea_auto;

  location.hash = "page2";

}

//第二步
function beforeSubmit(){
  var BenefiType = document.querySelector("#BenefiType").value;  //受益人类型
  var BenefiCiary = document.querySelector("#BenefiCiary").value;  //受益人姓名
  var BenefiCard = document.querySelector("#BenefiCard").value;  //受益人身份证号
  var BenefiCardEndDate = document.querySelector("#BenefiCardEndDate").value;  //收益人身份证有效期
  var creditFlag = document.querySelector("#creditFlag").value;
  var textarea_auto = document.querySelector("#textarea_auto").value;  //不良诚信记录
  var pro_mobile = document.querySelector("#pro_mobile").value;  //推荐人
  var broker = document.querySelector("#broker").value;  //客户经理
  var lowincome = document.querySelector("#lowincome").checked? 1:0;

  if(BenefiType==""){
    Com.showNativeAlert("","请选择账户实际受益人",["确定"]);
    //console.log("请选择账户实际受益人");
    return false;
  }

  if(BenefiType==1){
    if(BenefiCiary==""){
      Com.showNativeAlert("","受益人姓名不能为空",["确定"]);
      //console.log("受益人姓名不能为空");
      return false;
    }
    if(BenefiCard==""){
      Com.showNativeAlert("","受益人身份证号不能为空",["确定"]);
      //console.log("受益人身份证号不能为空");
      return false;
    }

    var validMsg = identityCodeValid(BenefiCard);
    if(validMsg!=""){
      Com.showNativeAlert("",validMsg,["确定"]);
      //console.log("身份证号不能为空");
      return false;
    }

    if(BenefiCardEndDate==""){
      Com.showNativeAlert("","受益人身份证有效期不能为空",["确定"]);
      //console.log("受益人身份证有效期不能为空");
      return false;
    }
  }
  if(creditFlag==""){
    Com.showNativeAlert("","请选择不良诚信记录",["确定"]);
    //console.log("请选择不良诚信记录");
    return false;
  }
  if(document.querySelector("#creditFlag").value==1 && document.querySelector("#textarea_auto").value==""){
    Com.showNativeAlert("","不良诚信记录不能为空",["确定"]);
    //console.log("不良诚信记录不能为空");
    return false;
  }
  if(!document.querySelector("#readmeCHK").checked){
    Com.showNativeAlert("","未同意签署协议",["确定"]);
    //console.log("未同意签署协议")
    return false;
  }

  BenefiCardEndDate = BenefiCardEndDate =="长期有效"? "30000101" : BenefiCardEndDate;

  __DATA.userinfo.BenefiType = BenefiType;
  __DATA.userinfo.lowincome = lowincome;
  __DATA.userinfo.creditFlag = creditFlag;
  __DATA.userinfo.BenefiCiary = BenefiCiary;
  __DATA.userinfo.BenefiCard = BenefiCard;
  __DATA.userinfo.BenefiCardEndDate = BenefiCardEndDate;
  __DATA.userinfo.CreditRecord = textarea_auto;
  __DATA.userinfo.pro_mobile = pro_mobile;
  __DATA.userinfo.broker = broker;

  var _BenefiType = 2 - BenefiType;
  var _creditFlag = 2 - creditFlag;

  var data = {
    idCode :__DATA.userinfo.ucNumber,  //身份证号码
    custName :__DATA.userinfo.ucName,  //姓名
    idIssUnit :__DATA.userinfo.ucIssueUint , //发证机关
    idBegDate :__DATA.userinfo.ucStartDate , //有效期开始时间
    idExpDate :__DATA.userinfo.ucEndDate,  //有效期结束时间 '30000101'表示长期有效
    idAddress :__DATA.userinfo.ucAddress,  //证件地址
    custSex : __DATA.userinfo.ucSex, //性别 男\女
    nativePlace :  __DATA.userinfo.ucNative, //籍贯
    address :__DATA.userinfo.contact_addr +  __DATA.userinfo.contact_detail_addr,// 住址
    zipCode : __DATA.userinfo.zipcode ,//邮编
    education:__DATA.userinfo.EDUCATION,// 学历 字典类型(0博士，1硕士，2本科，3大专，4中专，5高中，6初中以下，7其他)
    vocatoin :__DATA.userinfo.OCCU_EXTYPE,//职业  字典类型(01文教科卫专业人员,02党政机关工作人员.....)
    cifTrade :__DATA.userinfo.CIF_TRADE,// 行业标志  字典类型
    mobileTel:__DATA.userinfo.mobileTel,// 手机号
    nationality :__DATA.userinfo.ucNat,//民族（汉....）
    commenderCode :__DATA.userinfo.broker,//推荐人代码-经纪人代码
    referrerMobile :__DATA.userinfo.pro_mobile,//推荐人手机号
    lowIncomeFlag :__DATA.userinfo.lowincome + "",//是否为低保
    bnfFlag  :_BenefiType + "",// 是否有受益人 1:有受益人
    bnfName  :__DATA.userinfo.BenefiCiary,//受益人姓名，如果bnfFlag为1,必传
    bnfIdCode :__DATA.userinfo.BenefiCard, //受益人证件号码
    bnfIdExpDate :__DATA.userinfo.BenefiCardEndDate,// 受益人证件有效期
    creditFlag  :_creditFlag + "",// 诚信标志
    creditRecord :__DATA.userinfo.CreditRecord //诚信记录
  }

  $js.afterCommit = function(params){
    Com.showNativeAlert('',"已提交",["确定"]);
  }

  //年龄职业判断
  var age = getAge();
  if((age>0 && __DATA.userinfo.OCCU_EXTYPE=="03" && age < 25)||(age>0 && __DATA.userinfo.OCCU_EXTYPE=="09" && age >= 40) || (age>0 && __DATA.userinfo.OCCU_EXTYPE=="11" && age < 40)){
    Com.showNativeAlert('',"您的年龄与所选职业不匹配，请核对后再提交",['重新修改','继续提交'],function(params){
      if(params.clickedIndex==1){
        onCallNative('DataService','commitOpenAccountInfo',data);
      }
    })
  }else if("02,03,041,042,08".indexOf(__DATA.userinfo.OCCU_EXTYPE)>=0 && Number(__DATA.userinfo.EDUCATION) >= 6){
    //学历职业判断，职业02,03,041,042,08学历需在初中以上
    Com.showNativeAlert('',"您所选的职业与学历不匹配，请核对再提交",['重新修改','继续提交'],function(params){
      if(params.clickedIndex==1){
        onCallNative('DataService','commitOpenAccountInfo',data);
      }
    })
  }else{
    onCallNative('DataService','commitOpenAccountInfo',data);
  }
}

//根据ocr的出生年月日计算年龄
function getAge(){
  try{
    //截取身份证号6-10位
    var birth = __DATA.userinfo.ucNumber.substring(6,10);
    var age = birth? new Date().getFullYear() - Number(birth.substring(0,4)):-1;
  }catch(err){
    age = -1;
  }
  return age;
}

//设置日期控件
function setDateInput(){
  var isMobile=Com.clientType();

	if(isMobile=='android' || isMobile=='ios'){
    var datainputs = $('.dateinput');
		datainputs.attr('readonly','readonly');
    //日期输入框点击选择
		$('.dateinput').on('click',function(e){
      if(e.target.className.indexOf("disabled")>=0) return false;
      var id = e.target.id;
      var v = e.target.value;
			$js.setBeginDate = function(param){
        document.querySelector("#" + id).value = param.date;
			}
      v = v.replaceAll("-","");
      console.log("showing dateinput````");
			onCallNative('WebContainer','showDatePicker',{'date':v},'setBeginDate');
		});
	}
  // else if(isMobile=="ios"){
	// 	datainputs.attr('type','date');
  // }
}

//长期有效按钮
function setLongDateBtn(){
  //日期按钮点击选择
  $(".date-btn").on("click",function(e){
    $target = e.target;
    if(e.target.tagName!="BUTTON"){
      $target = e.target.parentNode;
    }
    var type = $target.dataset.type;
    var $p = $target.parentNode;

    if($p.className.indexOf(type) >=0 && type=="forever"){
      return false;
    }

    var $forinput = $("#" + $p.dataset.for);
    $p.className = "date-btn-grp " + type;
    if(type == "forever"){
      $p.dataset.oldv = $forinput.val();
      $forinput.val("长期有效");
      __DATA.userinfo[$p.dataset.for] = '30000101';
      $forinput.addClass("disabled");
    }else if(type=="calendar"){
      $forinput.val($p.dataset.oldv);
      $forinput.removeClass("disabled");
      $forinput.click();
      //onCallNative('WebContainer','showDatePicker',{'date':$p.dataset.oldv},'setBeginDate');
    }
  })
}

//设置picker
function setPickers(){
  var pickerTags = $(".picker-tag");
  for(var i = 0; i < pickerTags.length; i++){
    //读取相关属性
    var picker_for = pickerTags[i]["dataset"]["for"];
    var title = pickerTags[i]["dataset"]["title"];
    //是否已经选择过
    var selected = __DATA.userinfo[picker_for]? __DATA.userinfo[picker_for]:"";
    var index = getIndexByValue(picker_for, selected, "value");
    index = index < 0? 0:index;
    //如果是行业,且选择的职业是05-农民、07-待业，09-学生，11-离退休人员，12-收租
    if(picker_for=="CIF_TRADE" && document.querySelector("#OCCU_EXTYPE").value!="" &&"05,07,09,11,12".indexOf(document.querySelector("#OCCU_EXTYPE").value)>=0){
      var _name = getNameByValue(__DATA.OCCU_EXTYPES, document.querySelector("#OCCU_EXTYPE").value);
      document.querySelector("#showCIF_TRADE").innerHTML = _name;
      document.querySelector("#CIF_TRADE").value = document.querySelector("#OCCU_EXTYPE").value;
    }else if(__DATA.userinfo[picker_for]){
      var _name = getNameByValue(__DATA[picker_for+"S"], __DATA.userinfo[picker_for]);
      document.querySelector("#show" + picker_for).innerText = _name;
      document.querySelector("#" + picker_for).value = __DATA.userinfo[picker_for];
    }

    //创建选择器
    __DATA[picker_for+"Picker"] = new Picker({
    	data: [__DATA[picker_for+"S"]],
    	selectedIndex: [index],
    	title: title
    });
    __DATA[picker_for+"Picker"]["name"] = picker_for;
    __DATA[picker_for+"Picker"].on('picker.select', function (selectedVal, selectedIndex) {

      var item = null;
      if(this.name == "OCCU_EXTYPE" && document.querySelector("#EDUCATION").value == 6){
        item = __DATA[this.name+"S2"][selectedIndex[0]];
      }else{
        item = __DATA[this.name+"S"][selectedIndex[0]];
      }
	    document.querySelector("#show" + this.name).innerHTML = item.text;
      document.querySelector("#"+this.name).value = item.value;
      changeField(this.name,item);
    });
    $("#show" + picker_for).bind('click', function (e) {
      var $target = e.target.className.indexOf("picker-tag")>=0? e.target:e.target.parentNode;
      var disabled = $target.getAttribute("disabled");
      if(disabled) return false;
      var _for = $target.dataset.for;

      __DATA[_for+"Picker"] && __DATA[_for+"Picker"].show();

      //如果是选择职业，需要根据学历渲染职业范围
      if(_for=="OCCU_EXTYPE"){
        //学历为初中以下
        if(document.querySelector("#EDUCATION").value==6){
          setTimeout(function(){
            __DATA[_for+"Picker"].refillColumn(0,__DATA.OCCU_EXTYPES2);
            __DATA[_for+"Picker"].scrollColumn(0,0);
          },0)
        }else if(document.querySelector("#EDUCATION").value!=""){
          var selected = __DATA.userinfo[_for]? __DATA.userinfo[_for]:"";
          var index = getIndexByValue(_for, selected, "value");
          index = index < 0? 0:index;
          setTimeout(function(){
            __DATA[_for+"Picker"].refillColumn(0,__DATA.OCCU_EXTYPES);
            __DATA[_for+"Picker"].scrollColumn(0,index);
          },0)
        }
      }

    });
  }
}

//根据值获取选择列表索引
function getIndexByValue(name, value){
  var array = null;
  if(name=="OCCU_EXTYPE" && document.querySelector("#EDUCATION").value=="6"){
    array = __DATA.OCCU_EXTYPES2
  }else{
    array = __DATA[name + "S"];
  }
  var field = arguments[2]? arguments[2]:"";
  var index = -1;
  for(var i = 0; i < array.length; i++){
    if(field && array[i][field] == value){
      index = i;
      break;
    }else if(array[i] == value){
      index = i;
      break;
    }
  }
  return index;
}

function getNameByValue(array,value){
  var name ="";
  for(var i = 0; i < array.length; i++){
    if(array[i]["value"] == value){
      name = array[i]["text"];
      break;
    }
  }
  return name;
}

//修改学历、职业、行业
function changeField(name, item){
  if(name=="EDUCATION"){
    //如果学历为初中以下，则不显示职业011-教师、012-医生、10-证券从业人员
    if(item.value==6){
      //如果学历选择了初中以下且当前的职业为教师、医生、证券从业人员之一，需要重置职业
      if("011,012,10".indexOf(document.querySelector("#OCCU_EXTYPE").value)>=0){
        document.querySelector("#OCCU_EXTYPE").value = "";
        document.querySelector("#showOCCU_EXTYPE").innerHTML = '<span class="addr_area iptpdcolor" >请选择</span>';
        document.querySelector("#CIF_TRADE").value = "";
        document.querySelector("#showCIF_TRADE").innerHTML = '<span class="addr_area iptpdcolor" >请选择</span>';
        __DATA.switchs.CIF_TRADE = true;
      }
    }
  }else if(name=="OCCU_EXTYPE"){
    //如果是农民、农民、待业、学生、离退休、收租
    if("05,07,09,11,12".indexOf(item.value)>=0){
      document.querySelector("#CIF_TRADE").value = __DATA.OCCU_CIF[item.value];
      document.querySelector("#showCIF_TRADE").setAttribute("disabled",true);
      document.querySelector("#showCIF_TRADE").innerHTML = item.text;
      __DATA.switchs.CIF_TRADE = false;
    }else{
      document.querySelector("#CIF_TRADE").value = "";
      document.querySelector("#showCIF_TRADE").removeAttribute("disabled");
      document.querySelector("#showCIF_TRADE").innerHTML = '<span class="addr_area iptpdcolor" >请选择</span>';
      __DATA.switchs.CIF_TRADE = true;
    }
  }else if(name=="creditFlag"){
    __DATA.userinfo.creditFlag = item.value;
    if(item.value==1){
      $(".creditRecord-tr").removeClass("hide");
    }else{
      $(".creditRecord-tr").addClass("hide");
    }
  }else if(name=="BenefiType"){
    if(item.value==1){
      $(".benefi-tr").removeClass("hide");
    }else{
      $(".benefi-tr").addClass("hide");
    }
  }
  __DATA.userinfo[name] = item.value;
}

//校验身份证号码
function identityCodeValid(cardNo){
        var msg = "";
        if (15 != cardNo.length && 18 != cardNo.length) {
            msg = '身份证号输入位数不正确！';
            return msg;
        }
        if (15 == cardNo.length) {
            var year = cardNo.substring(6, 8);
            var month = cardNo.substring(8, 10);
            var day = cardNo.substring(10, 12);
            var p = cardNo.substring(14, 15); //性别位
            var birthday = new Date(year, parseFloat(month) - 1,
                parseFloat(day));
            // 对于老身份证中的年龄则不需考虑千年虫问题而使用getYear()方法
            if (birthday.getYear() != parseFloat(year)
                || birthday.getMonth() != parseFloat(month) - 1
                || birthday.getDate() != parseFloat(day)) {
                msg = '身份证号输入的出生日期不正确！';
            }
            return msg;
        }
        if (18 == cardNo.length) {
            var year = cardNo.substring(6, 10);
            var month = cardNo.substring(10, 12);
            var day = cardNo.substring(12, 14);
            var p = cardNo.substring(14, 17)
            var birthday = new Date(year, parseFloat(month) - 1,
                parseFloat(day));
            // 这里用getFullYear()获取年份，避免千年虫问题
            if (birthday.getFullYear() != parseFloat(year)
                || birthday.getMonth() != parseFloat(month) - 1
                || birthday.getDate() != parseFloat(day)) {
                msg = '身份证号输入的出生日期不正确！';
                return msg;
            }
            var Wi = [ 7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2, 1 ];// 加权因子
            var Y = [ 1, 0, 10, 9, 8, 7, 6, 5, 4, 3, 2 ];// 身份证验证位值.10代表X
            // 验证校验位
            var sum = 0; // 声明加权求和变量
            var _cardNo = cardNo.split("");
            if (_cardNo[17].toLowerCase() == 'x') {
                _cardNo[17] = 10;// 将最后位为x的验证码替换为10方便后续操作
            }
            for ( var i = 0; i < 17; i++) {
                sum += Wi[i] * _cardNo[i];// 加权求和
            }
            var i = sum % 11;// 得到验证码所位置
            if (_cardNo[17] != Y[i]) {
                msg = '身份证号校验不正确！';
                return msg;
            }
        }
        return msg;
    }
